@@ -2,17 +2,16 @@
  * Copyright (c) 2011-2012 - Mauro Carvalho Chehab
  * Copyright (c) 2012-2014 - Andre Roth <neolynx@gmail.com>
  *
- * This program is free software; you can redistribute it and/or
- * modify it under the terms of the GNU General Public License
- * as published by the Free Software Foundation version 2
- * of the License.
+ * This program is free software; you can redistribute it and/or modify
+ * it under the terms of the GNU Lesser General Public License as published by
+ * the Free Software Foundation version 2.1 of the License.
  *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
+ * GNU Lesser General Public License for more details.
  *
- * You should have received a copy of the GNU General Public License
+ * You should have received a copy of the GNU Lesser General Public License
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
  * Or, point your browser to http://www.gnu.org/licenses/old-licenses/gpl-2.0.html
@@ -23,7 +22,7 @@
  * @ingroup dvb_table
  * @brief Provides a way to handle MPEG-TS descriptors found on Digital TV
  * 	streams.
- * @copyright GNU General Public License version 2 (GPLv2)
+ * @copyright GNU Lesser General Public License version 2.1 (LGPLv2.1)
  * @author Mauro Carvalho Chehab
  * @author Andre Roth
  *
@@ -126,11 +125,13 @@ struct dvb_desc {
 #ifndef _DOXYGEN
 
 #define dvb_desc_foreach( _desc, _tbl ) \
-	for( struct dvb_desc *_desc = _tbl->descriptor; _desc; _desc = _desc->next ) \
+	if (_tbl && _tbl->descriptor) \
+		for( struct dvb_desc *_desc = _tbl->descriptor; _desc; _desc = _desc->next ) \
 
 #define dvb_desc_find(_struct, _desc, _tbl, _type) \
-	for( _struct *_desc = (_struct *) _tbl->descriptor; _desc; _desc = (_struct *) _desc->next ) \
-		if(_desc->type == _type) \
+	if (_tbl && _tbl->descriptor) \
+		for( _struct *_desc = (_struct *) _tbl->descriptor; _desc; _desc = (_struct *) _desc->next ) \
+			if(_desc->type == _type) \
 
 #endif /* _DOXYGEN */
 
